﻿using System;
using System.Threading.Tasks;
using Fifa.ConnectId.Sdk.Core;
using Fifa.ConnectServiceBus.Sdk.Authentication;
using Fifa.ConnectServiceBus.Sdk.Logging;

namespace LocalNuGetFeedDemoProject
{
    internal class Program
    {
        static async Task Main()
        {
            var logger = new ConsoleLogger();
            const string clientId = "<client_id>";
            const string secretKey = "<client_secret_key>";
            var environment = ConnectIdEnvironment.Beta;// make sure that the credentials match the environment



            var credentials = new ClientCredentials(clientId, secretKey);
            try
            {
                var fifaConnectIdClient = new FifaConnectIdClient(environment, credentials, logger);
                const string fifaOrganisationId = "105C3ZB";

                var fifaOrganisationLocalType = await fifaConnectIdClient.GetOrganisationAsync(fifaOrganisationId);
                Console.WriteLine($"{fifaOrganisationLocalType.InternationalShortName} Connect ID SDKs are now available as NuGet packages!");
            }
            catch (Exception e)
            {
                logger.Error(e, e.Message);
            }
            
            Console.WriteLine("Press any key to close...");
            Console.ReadKey();
        }

        class ConsoleLogger : ILogger
        {
            public void Debug(string message, params object[] args)
            {
                
            }

            public void Error(string message, params object[] args)
            {
                Console.WriteLine($"[ERROR] {message}", args);
            }

            public void Error(Exception exception, string message, params object[] args)
            {
                Console.WriteLine($"[ERROR] {message}. Exception: {exception}", args);
            }
        }
    }
}